@@ -11,3 +11,8 @@ def print_msg_box(msg, indent=1, width=None, title=None):
     box += ''.join([f'║{space}{line:<{width}}{space}║\n' for line in lines])
     box += f'╚{"═" * (width + indent * 2)}╝'  # lower_border
     print(box)
+
+def file_output(msg,file_name):
+    file = open(file_name, 'w')
+    file.write(msg)
+    file.close()
\ No newline at end of file
