@@ -1,4 +1,4 @@
-from .__init__ import print_msg_box
+from .__init__ import print_msg_box,file_output
 import time
 import numpy as np
 from itertools import permutations
@@ -113,7 +113,7 @@ class matrices:
 class sorting:
 
     # bubble sort algorithm
-    def bubble_sort(self,arr,hint=False):
+    def bubble_sort(self,arr,file_name,hint=False,file=False):
         start = time.time()
         for i in range(len(arr)-1):
             for j in range(len(arr)-i-1):
@@ -123,10 +123,10 @@ class sorting:
         end = time.time()
         print("Bubble Sort Runtime = {} seconds".format(end-start))
         if(hint == True):
-            self.bubble_sort_hint()
+            self.bubble_sort_hint(file_name,file)
         return arr
 
-    def bubble_sort_hint(self):
+    def bubble_sort_hint(self,file_name,flag=False):
         message ="""
         Bubble Sort
         ------------------------------------
@@ -174,7 +174,10 @@ class sorting:
 
         Learn More Here - https://en.wikipedia.org/wiki/Bubble_sort
         """
-        print_msg_box(message)
+        if(flag == True):
+            file_output(message,file_name)
+        else:
+            print_msg_box(message)
 
     # selection Sort Algorithm
     def selection_sort(self,arr,hint=False):
@@ -1507,4 +1510,9 @@ class dynamic_programming:
 # ping = matrices()
 
 # ping.setZeros(img_arr,3,3)
-# print(img_arr)
\ No newline at end of file
+# print(img_arr)
+
+# ping1 = sorting()
+# arr = [7,53,35,2356,2,3,5,2]
+
+# arr = ping1.bubble_sort(arr,'output.txt',True,True)
\ No newline at end of file
